Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1481)

Unified Diff: content/shell/browser/layout_test/layout_test_notification_manager.h

Issue 2403893002: Add layout test for reply property of notificationclick event (Closed)
Patch Set: Make reply field nullable in .idl files; add test cases for empty and null Created 4 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/shell/browser/layout_test/layout_test_notification_manager.h
diff --git a/content/shell/browser/layout_test/layout_test_notification_manager.h b/content/shell/browser/layout_test/layout_test_notification_manager.h
index 2ed42ac9cb876a96989976d44e80271c01b38178..150d5d9158adb6155fce17d69c7fadbb30c3e66d 100644
--- a/content/shell/browser/layout_test/layout_test_notification_manager.h
+++ b/content/shell/browser/layout_test/layout_test_notification_manager.h
@@ -31,8 +31,11 @@ class LayoutTestNotificationManager : public PlatformNotificationService {
// Simulates a click on the notification titled |title|. |action_index|
// indicates which action was clicked, or -1 if the main notification body was
- // clicked. Must be called on the UI thread.
- void SimulateClick(const std::string& title, int action_index);
+ // clicked. |reply| indicates the user reply, if any.
+ // Must be called on the UI thread.
+ void SimulateClick(const std::string& title,
+ int action_index,
+ const base::NullableString16& reply);
// Simulates the closing a notification titled |title|. Must be called on
// the UI thread.

Powered by Google App Engine
This is Rietveld 408576698